searchNodes=[{"ref":"Tabular.html","title":"Tabular","type":"module","doc":"Tabular converts an ascii table string into either a list of lists or a list of maps."},{"ref":"Tabular.html#to_list_of_lists/2","title":"Tabular.to_list_of_lists/2","type":"function","doc":"Converts an ascii table to a list of lists. Examples iex&gt; ascii_table = &quot;&quot;&quot; ...&gt; |---------------+--------------------| ...&gt; | name | dob | ...&gt; |---------------+--------------------| ...&gt; | Malcolm | September 20, 2468 | ...&gt; | Reynolds | | ...&gt; |---------------+--------------------| ...&gt; | Zoe Washburne | February 15, 2484 | ...&gt; |---------------+--------------------| ...&gt; &quot;&quot;&quot; ...&gt; Tabular.to_list_of_lists(ascii_table) [ [&quot;name&quot;, &quot;dob&quot;], [&quot;Malcolm Reynolds&quot;, &quot;September 20, 2468&quot;], [&quot;Zoe Washburne&quot;, &quot;February 15, 2484&quot;] ] ...&gt; Tabular.to_list_of_lists(ascii_table, header: false) [ [&quot;Malcolm Reynolds&quot;, &quot;September 20, 2468&quot;], [&quot;Zoe Washburne&quot;, &quot;February 15, 2484&quot;] ] Without separators: iex&gt; ascii_table = &quot;&quot;&quot; ...&gt; |------------------+--------------------| ...&gt; | name | dob | ...&gt; |------------------+--------------------| ...&gt; | Malcolm Reynolds | September 20, 2468 | ...&gt; | Zoe Washburne | February 15, 2484 | ...&gt; |------------------+--------------------| ...&gt; &quot;&quot;&quot; ...&gt; Tabular.to_list_of_lists(ascii_table) [ [&quot;name&quot;, &quot;dob&quot;], [&quot;Malcolm Reynolds&quot;, &quot;September 20, 2468&quot;], [&quot;Zoe Washburne&quot;, &quot;February 15, 2484&quot;] ] ...&gt; Tabular.to_list_of_lists(ascii_table, header: false) [ [&quot;Malcolm Reynolds&quot;, &quot;September 20, 2468&quot;], [&quot;Zoe Washburne&quot;, &quot;February 15, 2484&quot;] ]"},{"ref":"Tabular.html#to_list_of_lists_no_header/1","title":"Tabular.to_list_of_lists_no_header/1","type":"function","doc":"Converts an ascii table to a list of lists, omitting the header row. Examples iex&gt; ascii_table = &quot;&quot;&quot; ...&gt; |---------------+--------------------| ...&gt; | name | dob | ...&gt; |---------------+--------------------| ...&gt; | Malcolm | September 20, 2468 | ...&gt; | Reynolds | | ...&gt; |---------------+--------------------| ...&gt; | Zoe Washburne | February 15, 2484 | ...&gt; |---------------+--------------------| ...&gt; &quot;&quot;&quot; ...&gt; Tabular.to_list_of_lists_no_header(ascii_table) [ [&quot;Malcolm Reynolds&quot;, &quot;September 20, 2468&quot;], [&quot;Zoe Washburne&quot;, &quot;February 15, 2484&quot;] ] Without separators: iex&gt; ascii_table = &quot;&quot;&quot; ...&gt; |------------------+--------------------| ...&gt; | name | dob | ...&gt; |------------------+--------------------| ...&gt; | Malcolm Reynolds | September 20, 2468 | ...&gt; | Zoe Washburne | February 15, 2484 | ...&gt; |------------------+--------------------| ...&gt; &quot;&quot;&quot; ...&gt; Tabular.to_list_of_lists_no_header(ascii_table) [ [&quot;Malcolm Reynolds&quot;, &quot;September 20, 2468&quot;], [&quot;Zoe Washburne&quot;, &quot;February 15, 2484&quot;] ]"},{"ref":"Tabular.html#to_list_of_maps/1","title":"Tabular.to_list_of_maps/1","type":"function","doc":"Converts an ascii table to a list of maps. Examples iex&gt; ascii_table = &quot;&quot;&quot; ...&gt; |---------------+--------------------| ...&gt; | name | dob | ...&gt; |---------------+--------------------| ...&gt; | Malcolm | September 20, 2468 | ...&gt; | Reynolds | | ...&gt; |---------------+--------------------| ...&gt; | Zoe Washburne | February 15, 2484 | ...&gt; |---------------+--------------------| ...&gt; &quot;&quot;&quot; ...&gt; Tabular.to_list_of_maps(ascii_table) [ %{dob: &quot;September 20, 2468&quot;, name: &quot;Malcolm Reynolds&quot;}, %{dob: &quot;February 15, 2484&quot;, name: &quot;Zoe Washburne&quot;} ] Without separators: iex&gt; ascii_table = &quot;&quot;&quot; ...&gt; |------------------+--------------------| ...&gt; | name | dob | ...&gt; |------------------+--------------------| ...&gt; | Malcolm Reynolds | September 20, 2468 | ...&gt; | Zoe Washburne | February 15, 2484 | ...&gt; |------------------+--------------------| ...&gt; &quot;&quot;&quot; ...&gt; Tabular.to_list_of_maps(ascii_table) [ %{dob: &quot;September 20, 2468&quot;, name: &quot;Malcolm Reynolds&quot;}, %{dob: &quot;February 15, 2484&quot;, name: &quot;Zoe Washburne&quot;} ]"},{"ref":"Tabular.TestSupport.html","title":"Tabular.TestSupport","type":"module","doc":"Functions to simplify testing with ascii tables. compare/2 compares two ascii tables, producing a matrix of the individual comparisons. equal?/1 examines the matrix generated by compare/2 and returns true if all cells are true and false otherwise."},{"ref":"Tabular.TestSupport.html#assert_equal/1","title":"Tabular.TestSupport.assert_equal/1","type":"function","doc":""},{"ref":"Tabular.TestSupport.html#compare/3","title":"Tabular.TestSupport.compare/3","type":"function","doc":"Compares two ascii tables producing a matrix of individual cell comparison results. Optional comparator functions can be provided. Examples iex&gt; table1 = &quot;&quot;&quot; ...&gt; +---------+-------+ ...&gt; | name | count | ...&gt; +---------+-------+ ...&gt; | Malcolm | 10 | ...&gt; +---------+-------+ ...&gt; | Zoe | 5 | ...&gt; +---------+-------+ ...&gt; &quot;&quot;&quot; ...&gt; ...&gt; table2 = &quot;&quot;&quot; ...&gt; +---------+-------+ ...&gt; | name | count | ...&gt; +---------+-------+ ...&gt; | Mike | 11 | ...&gt; +---------+-------+ ...&gt; | Zoe | 20 | ...&gt; +---------+-------+ ...&gt; &quot;&quot;&quot; ...&gt; ...&gt; comparators = %{&quot;count&quot; =&gt; &amp;(abs(String.to_integer(&amp;1) - String.to_integer(&amp;2)) &lt; 2)} ...&gt; ...&gt; Tabular.TestSupport.compare(table1, table2, comparators: comparators) [ [false, true], [true, false] ]"},{"ref":"Tabular.TestSupport.html#equal?/1","title":"Tabular.TestSupport.equal?/1","type":"function","doc":"Examines the matrix produced by compare/2. Returns false if any cell is false. Otherwise returns true. Examples iex&gt; results_table = [ ...&gt; [true, true, true], ...&gt; [true, false, true], ...&gt; [true, true, true] ...&gt; ] ...&gt; ...&gt; Tabular.TestSupport.equal?(results_table) false"},{"ref":"Tabular.TestSupport.html#format_cells/1","title":"Tabular.TestSupport.format_cells/1","type":"function","doc":""},{"ref":"Tabular.TestSupport.html#generate_error_message/1","title":"Tabular.TestSupport.generate_error_message/1","type":"function","doc":""},{"ref":"readme.html","title":"Tabular","type":"extras","doc":"Tabular Tabular is a reader for data in ascii table format and test helpers to facilitate testing with ascii tables."},{"ref":"readme.html#reader","title":"Tabular - Reader","type":"extras","doc":"The reader allows you to read string data formatted like this: +------------------+--------------------+ | name | dob | +------------------+--------------------+ | Malcolm Reynolds | September 20, 2468 | | Zoe Washburne | February 15, 2484 | +------------------+--------------------+ You can add row separators so that column values can wrap over multiple rows. This helps you manage the width of tables. +-----------+--------------+ | name | dob | +-----------+--------------+ | Malcolm | September 20,| | Reynolds | 2468 | +-----------+--------------+ | Zoe | February 15, | | Washburne | 2484 | +-----------+--------------+ Wrapped cells are folded--the two tables produce the same results."},{"ref":"readme.html#test-helpers","title":"Tabular - Test Helpers","type":"extras","doc":"The compare/2 and equal?/1 functions can compare two ascii tables. Compare/2 generates a matrix from two ascii tables indicating which cells are equal and which are different. You can provide an optional list of comparators associated with a column. When a comparator is provided for a column it will be used to compare the values of the cells for that column. See test_support_test.exs for examples that include comparators. Equal?/1 takes the matrix generated by compare and returns a boolean indicating if original ascii tables are, well, equal. In Ascii Tables For Clearer Testing I discuss using ascii tables to improve comprehension of software tests."},{"ref":"readme.html#installation","title":"Tabular - Installation","type":"extras","doc":"The package can be installed by adding tabular to your list of dependencies in mix.exs: def deps do [ {:tabular, &quot;~&gt; 0.3.0&quot;} ] end"},{"ref":"readme.html#usage","title":"Tabular - Usage","type":"extras","doc":"Rows are returned as either lists of lists or lists of maps. +-----------------------+------------------------------+-----------------------------------+ | **Ascii Table Value** | **Returned Value** | **Notes** | +-----------------------+------------------------------+-----------------------------------+ | Malcolm Reynolds | \"Malcolm Reynolds\" | Most values returned as string | +-----------------------+------------------------------+-----------------------------------+ | 123 | \"123\" | including numbers | +-----------------------+------------------------------+-----------------------------------+ | wrapped strings are | \"wrapped strings are folded\" | Similar to yaml, wrapped | | folded | | strings are folded with a single | | | | space replacing the new line | +-----------------------+------------------------------+-----------------------------------+ | | \"\" | an empty string is returned for | | | | blank cells | +-----------------------+------------------------------+-----------------------------------+ | nil | nil | nil, true, and false are | | | | special values | +-----------------------+------------------------------+-----------------------------------+ | true | true | | +-----------------------+------------------------------+-----------------------------------+ | false | false | | +-----------------------+------------------------------+-----------------------------------+ | :foo | :foo | Values beginning with a colon are | | | | returned as atoms | +-----------------------+------------------------------+-----------------------------------+ Reading a String Tabular.to_list_of_lists(table) |&gt; Enum.each(fn [col1, col2, col3] = row -&gt; # use row or column data here... end More examples can be found in the Examples of Testing With ASCII Tables repo. The docs can be found at https://hexdocs.pm/tabular."},{"ref":"readme.html#license","title":"Tabular - License","type":"extras","doc":"Blue Oak Model license. Please see LICENSE for details."}]